@@ -16,7 +16,6 @@
 #include <KMessageBox>
 #include <KStringHandler>
 #include <KWallet>
-#include <kwidgetsaddons_version.h>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
@@ -53,7 +52,7 @@ void Transport::loadPassword()
     }
 }
 
-QString Transport::password()
+QString Transport::password() const
 {
     return d->password;
 }
@@ -66,6 +65,7 @@ void Transport::setPassword(const QString &passwd)
     }
     d->passwordDirty = true;
     d->password = passwd;
+    Q_EMIT passwordChanged();
 }
 
 void Transport::forceUniqueName()
@@ -101,6 +101,7 @@ void Transport::updatePasswordState()
         d->password = original->d->password;
         d->passwordLoaded = original->d->passwordLoaded;
         d->passwordDirty = original->d->passwordDirty;
+        Q_EMIT passwordChanged();
     } else {
         qCWarning(MAILTRANSPORT_LOG) << "Transport with this ID not managed by transport manager.";
     }
@@ -169,6 +170,7 @@ void Transport::usrRead()
             qCWarning(MAILTRANSPORT_LOG) << "Type unknown to manager.";
             d->transportType.d->mName = i18nc("An unknown transport type", "Unknown");
         }
+        Q_EMIT transportTypeChanged();
     }
 
     // we have everything we need
@@ -189,9 +191,9 @@ void Transport::usrRead()
     if (!d->password.isEmpty()) {
         d->passwordLoaded = true;
         if (KWallet::Wallet::isEnabled()) {
-            //TODO: Needs to replaced with a check, if a backend is available.
-            // 2022-10-12: QtKeyChain has no method to request, if there is any backend.
-            // see https://github.com/frankosterfeld/qtkeychain/issues/224
+            // TODO: Needs to replaced with a check, if a backend is available.
+            //  2022-10-12: QtKeyChain has no method to request, if there is any backend.
+            //  see https://github.com/frankosterfeld/qtkeychain/issues/224
             d->needsWalletMigration = true;
         } else {
             d->storePasswordInFile = true;
@@ -204,33 +206,25 @@ bool Transport::usrSave()
     if (requiresAuthentication() && storePassword() && d->passwordDirty) {
         const QString storePassword = d->password;
         auto writeJob = new WritePasswordJob(WALLET_FOLDER, this);
-        connect(writeJob, &Job::finished, this, [=]{
+        connect(writeJob, &Job::finished, this, [=] {
             if (writeJob->error()) {
                 qWarning(MAILTRANSPORT_LOG()) << "WritePasswordJob failed with: " << writeJob->errorString();
                 // wallet saving failed, ask if we should store in the config file instead
                 if (d->storePasswordInFile
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                     || KMessageBox::warningTwoActions(nullptr,
-#else
-                    || KMessageBox::warningYesNo(nullptr,
-#endif
-                                                  i18n("QKeychain not found a backend for storing your password. "
-                                                       "It is strongly recommended to use strong backend for managing your passwords.\n"
-                                                       "However, the password can be stored in the configuration "
-                                                       "file instead. The password is stored in an obfuscated format, "
-                                                       "but should not be considered secure from decryption efforts "
-                                                       "if access to the configuration file is obtained.\n"
-                                                       "Do you want to store the password for server '%1' in the "
-                                                       "configuration file?",
-                                                       name()),
-                                                  i18n("KWallet Not Available"),
-                                                  KGuiItem(i18n("Store Password")),
-                                                  KGuiItem(i18n("Do Not Store Password")))
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-                    == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-                    == KMessageBox::Yes) {
-#endif
+                                                      i18n("QKeychain not found a backend for storing your password. "
+                                                           "It is strongly recommended to use strong backend for managing your passwords.\n"
+                                                           "However, the password can be stored in the configuration "
+                                                           "file instead. The password is stored in an obfuscated format, "
+                                                           "but should not be considered secure from decryption efforts "
+                                                           "if access to the configuration file is obtained.\n"
+                                                           "Do you want to store the password for server '%1' in the "
+                                                           "configuration file?",
+                                                           name()),
+                                                      i18n("KWallet Not Available"),
+                                                      KGuiItem(i18n("Store Password")),
+                                                      KGuiItem(i18n("Do Not Store Password")))
+                        == KMessageBox::ButtonCode::PrimaryAction) {
                     // write to config file
                     KConfigGroup group(config(), currentGroup());
                     group.writeEntry("password", KStringHandler::obscure(storePassword));
@@ -282,6 +276,7 @@ void Transport::readTransportPasswordFinished(QKeychain::Job *baseJob)
         d->password.clear();
         d->passwordLoaded = false;
         qWarning() << "We have an error during reading password " << job->errorString();
+        Q_EMIT passwordChanged();
     } else {
         setPassword(job->textData());
     }
